A few Functions for manipulating images
Author: Julien Mairal

## 6 A few Functions for manipulating images

- Function mexExtractPatches
- Function mexCombinePatches
- Function mexConvFistaFlat

This functions are not well documented yet

### 6.1 Function mexExtractPatches

# # The python function is not yet implemented. #

### 6.2 Function mexCombinePatches

# # The python function is not yet implemented. #

### 6.3 Function mexConvFistaFlat

# # The python function is not yet implemented. #